@@ -48,7 +48,10 @@ pub fn main() -> Result<(), anyhow::Error> {
     let arg_matches = app.get_matches();
 
     match arg_matches.subcommand() {
-        ("aqua", Some(args)) => aqua(args),
+        ("aqua", Some(args)) => {
+            // avoid printing version
+            return aqua(args);
+        }
         ("build", Some(args)) => build(args),
         ("set", Some(args)) => set(args),
         ("it", Some(args)) => it(args),
@@ -57,6 +60,11 @@ pub fn main() -> Result<(), anyhow::Error> {
         (c, _) => Err(crate::errors::CLIError::NoSuchCommand(c.to_string()).into()),
     }?;
 
+    // avoid printing version update into not TTY targets
+    if !atty::is(atty::Stream::Stdout) {
+        return Ok(());
+    }
+
     if let Ok(Some(new_version)) = check_latest::check_max!() {
         use termion::color;
 
@@ -94,7 +102,7 @@ fn aqua(args: &clap::ArgMatches<'_>) -> Result<(), anyhow::Error> {
         None => {
             let service_name = wasm_path
                 .file_stem()
-                .ok_or(anyhow::Error::msg("provided path isn't a path to a file"))?;
+                .ok_or_else(|| anyhow::Error::msg("provided path isn't a path to a file"))?;
 
             service_name.to_string_lossy()
         }
